@@ -20,17 +20,22 @@
 #' explicit value. SHAP values of dummy variables can be combined using the convenient
 #' \code{collapse} argument.
 #' @importFrom xgboost xgb.train
-#' @param object Object to be converted to an object of type "shapviz".
-#' @param X Corresponding matrix or data.frame of feature values used for visualization.
+#' @param object For XGBoost, LightGBM, and H2O, this is the fitted model used to
+#' calculate SHAP values from \code{X_pred}.
+#' In the other cases, it is the object containing the SHAP values.
+#' @param X Matrix or data.frame of feature values used for visualization.
+#' It must contain at least the same column names as the SHAP matrix represented by
+#' \code{object}/\code{X_pred} (after optionally collapsing some of the SHAP columns).
 #' @param X_pred Data set as expected by the \code{predict} function of
 #' XGBoost, LightGBM, or H2O. For XGBoost, a matrix or \code{xgb.DMatrix},
 #' for LightGBM a matrix, and for H2O a \code{data.frame} or an \code{H2OFrame}.
+#' Only used for XGBoost, LightGBM, or H2O objects.
 #' @param baseline Optional baseline value, representing the average response at the
 #' scale of the SHAP values. It will be used for plot methods that explain single
 #' predictions.
 #' @param which_class In case of a multiclass or multioutput setting,
 #' which class/output (>= 1) to explain. Currently relevant for XGBoost, LightGBM,
-#' or kernelshap.
+#' and kernelshap.
 #' @param collapse A named list of character vectors. Each vector specifies a group of
 #' column names in the SHAP matrix that should be collapsed to a single column by summation.
 #' The name of the new column equals the name of the vector in \code{collapse}.
@@ -68,21 +73,21 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL, ...) {
   object <- collapse_shap(object, collapse = collapse)
   stopifnot(
     "'X' must be a matrix or data.frame" = is.matrix(X) || is.data.frame(X),
+    "'object' need at least one row and one column" = dim(object) >= 1L,
+    "'X' need at least one row and one column" = dim(X) >= 1L,
     "The number of rows of 'object' and 'X' differ" = nrow(object) == nrow(X),
-    "The number of columns of 'object' and 'X' differ" = ncol(object) == ncol(X),
-    "'X' and 'object' need at least one row and one column" = dim(X) >= 1L,
-    "SHAP matrix must have column names" = !is.null(colnames(object)),
+    "'object' must have column names" = !is.null(colnames(object)),
     "'X' must have column names" = !is.null(colnames(X)),
-    "'object' and 'X' must have the same column names" =
-      sort(colnames(object)) == sort(colnames(X)),
+    "'X' must contain all column names of 'object'" =
+      all(colnames(object) %in% colnames(X)),
     "No missing SHAP values allowed" = !anyNA(object),
     "'baseline' has to be a single number" =
       length(baseline) == 1L && is.numeric(baseline),
     "'baseline' cannot be NA" = !is.na(baseline)
   )
   out <- list(
-    S = object[, colnames(X), drop = FALSE],
-    X = as.data.frame(X),
+    S = object,
+    X = as.data.frame(X)[colnames(object)],
     baseline = baseline
   )
   class(out) <- "shapviz"
@@ -98,14 +103,15 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL, ...) {
 #'
 #' # Will use numeric matrix "X_pred" as feature matrix
 #' x <- shapviz(fit, X_pred = X_pred)
-#' sv_importance(x)
+#' x
+#' sv_dependence(x, "Species")
 #'
 #' # Will use original values as feature matrix
-#' x <- shapviz(fit, X_pred = X_pred, X = iris[, -1])
-#' sv_dependence(x, "Petal.Length", color_var = "auto")
+#' x <- shapviz(fit, X_pred = X_pred, X = iris)
+#' sv_dependence(x, "Species", color_var = "auto")
 #'
 #' # "X_pred" can also be passed as xgb.DMatrix, but only if X is passed as well!
-#' x <- shapviz(fit, X_pred = dtrain, X = iris[, -1])
+#' x <- shapviz(fit, X_pred = dtrain, X = iris)
 #'
 #' # Similarly with LightGBM
 #' if (requireNamespace("lightgbm", quietly = TRUE)) {
@@ -132,9 +138,10 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL, ...) {
 #' x <- shapviz(
 #'   fit,
 #'   X_pred = X_pred,
-#'   X = iris[, -1],
+#'   X = iris,
 #'   collapse = list(Species = c("Speciessetosa", "Speciesversicolor", "Speciesvirginica"))
 #' )
+#' x
 shapviz.xgb.Booster = function(object, X_pred, X = X_pred,
                                which_class = NULL, collapse = NULL, ...) {
   stopifnot(
@@ -249,24 +256,21 @@ shapviz.kernelshap <- function(object, X = object[["X"]],
 
 #' @describeIn shapviz Creates a "shapviz" object from a (tree-based) H2O regression model.
 #' @export
-shapviz.H2ORegressionModel = function(object, X_pred,
-                                      X = as.data.frame(X_pred)[object@parameters[["x"]]],
+shapviz.H2ORegressionModel = function(object, X_pred, X = as.data.frame(X_pred),
                                       collapse = NULL, ...) {
   shapviz.H2OModel(object = object, X_pred = X_pred, X = X, collapse = collapse, ...)
 }
 
 #' @describeIn shapviz Creates a "shapviz" object from a (tree-based) H2O binary classification model.
 #' @export
-shapviz.H2OBinomialModel = function(object, X_pred,
-                                    X = as.data.frame(X_pred)[object@parameters[["x"]]],
+shapviz.H2OBinomialModel = function(object, X_pred, X = as.data.frame(X_pred),
                                     collapse = NULL, ...) {
   shapviz.H2OModel(object = object, X_pred = X_pred, X = X, collapse = collapse, ...)
 }
 
 #' @describeIn shapviz Creates a "shapviz" object from a (tree-based) H2O model (base class).
 #' @export
-shapviz.H2OModel = function(object, X_pred,
-                            X = as.data.frame(X_pred)[object@parameters[["x"]]],
+shapviz.H2OModel = function(object, X_pred, X = as.data.frame(X_pred),
                             collapse = NULL, ...) {
   if (!requireNamespace("h2o", quietly = TRUE)) {
     stop("Package 'h2o' not installed")
@@ -287,84 +291,3 @@ shapviz.H2OModel = function(object, X_pred,
     collapse = collapse
   )
 }
-
-#' Initialize "shapviz" Object from XGBoost/LightGBM Predict (Deprecated)
-#'
-#' These functions create an object of class "shapviz" by taking the output of
-#' \code{predict(..., predcontrib = TRUE)} of an XGBoost or LightGBM model,
-#' together with a matrix/data.frame \code{X} representing the corresponding
-#' feature values. These functions are mainly written for internal use
-#' but they can be useful if SHAP values have already been computed.
-#' Note that the SHAP matrix returned by LightGBM does not provide column names.
-#' Thus, you need to be absolutely sure that the column names of \code{X}
-#' correspond to the column names originally passed to \code{predict()}.
-#'
-#' @param S Output of calling \code{predict(..., predcontrib = TRUE)}.
-#' @param X Matrix or data.frame of feature values corresponding to \code{S}.
-#' @param which_class In case of a multiclass setting, which class >= 1 to explain.
-#' @param ... Other parameters passed (currently unused).
-#' @return An object of class "shapviz".
-#' @name from_xgb_or_lgb
-NULL
-
-#' @rdname from_xgb_or_lgb
-#' @export
-#' @examples
-#' X_pred <- data.matrix(iris[, -1])
-#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = iris[, 1])
-#' fit <- xgboost::xgb.train(data = dtrain, nrounds = 50)
-#' shap_values <- predict(fit, dtrain, predcontrib = TRUE)
-#' x <- shapviz_from_xgb_predict(shap_values, iris[, -1])
-shapviz_from_xgb_predict <- function(S, X, which_class = NULL, ...) {
-  warning("This function is deprecated and will be removed in version 0.3.0.")
-  # Reduce multiclass setting
-  if (is.list(S)) {
-    m <- length(S)
-    stopifnot(
-      !is.null(which_class),
-      which_class <= m
-    )
-    S <- S[[which_class]]
-  }
-  stopifnot(
-    is.matrix(S),
-    is.matrix(X) || is.data.frame(X),
-    nrow(S) == nrow(X),
-    ncol(S) == ncol(X) + 1L,
-    !is.null(colnames(S)),
-    !is.null(colnames(X)),
-    sort(colnames(S)) == sort(c(colnames(X), "BIAS"))
-  )
-  shapviz.matrix(
-    S[, colnames(X), drop = FALSE],
-    X = X,
-    baseline = unname(S[1L, "BIAS"])
-  )
-}
-
-#' @rdname from_xgb_or_lgb
-#' @export
-shapviz_from_lgb_predict <- function(S, X, which_class = NULL, ...) {
-  warning("This function is deprecated and will be removed in version 0.3.0.")
-  pp <- ncol(X) + 1L
-  stopifnot(
-    is.matrix(S),
-    is.matrix(X) || is.data.frame(X),
-    nrow(S) == nrow(X),
-    ncol(S) %% pp == 0,
-    !is.null(colnames(X))
-  )
-  # Reduce multiclass setting
-  m <- ncol(S) %/% pp
-  if (m >= 2L) {
-    stopifnot(
-      !is.null(which_class),
-      which_class <= m
-    )
-    S <- S[, 1:pp + pp * (which_class - 1), drop = FALSE]
-  }
-  baseline <- S[1L, pp]
-  S <- S[, -pp, drop = FALSE]
-  colnames(S) <- colnames(X)
-  shapviz.matrix(S, X = X, baseline = baseline)
-}
