@@ -17,7 +17,6 @@
 #' @param format_feat Function used to format numeric feature values. The default uses
 #' the global option \code{shapviz.format_feat}, which equals to
 #' \code{function(z) prettyNum(z, digits = 3, scientific = FALSE)} by default.
-#' @param format_fun Deprecated. Use \code{format_shap} and/or \code{format_feat} instead.
 #' @param contrast Logical flag that detemines whether to use white text in dark arrows.
 #' Default is \code{TRUE}.
 #' @param bar_label_size Size of text used to describe bars.
@@ -52,7 +51,6 @@ sv_force.shapviz <- function(object, row_id = 1L, max_display = 6L,
                              fill_colors = c("#f7d13d", "#a52c60"),
                              format_shap = getOption("shapviz.format_shap"),
                              format_feat = getOption("shapviz.format_feat"),
-                             format_fun = NULL,
                              contrast = TRUE, bar_label_size = 3.2,
                              show_annotation = TRUE, annotation_size = 3.2, ...) {
   stopifnot(
@@ -61,10 +59,6 @@ sv_force.shapviz <- function(object, row_id = 1L, max_display = 6L,
     "format_shap must be a function" = is.function(format_shap),
     "format_feat must be a function" = is.function(format_feat)
   )
-  if (!is.null(format_fun)) {
-    warning("format_fun is deprecated and will be removed in version 0.3.0.
-            Use format_shap and/or format_feat instead.")
-  }
 
   X <- get_feature_values(object)[row_id, ]
   S <- get_shap_values(object)[row_id, ]
