@@ -34,7 +34,7 @@ test_that("shapviz works with single row input", {
   shp1 <- shapviz(S[1L, , drop = FALSE], X[1L, , drop = FALSE], baseline = 4)
   expect_s3_class(sv_waterfall(shp1), "ggplot")
   expect_s3_class(sv_force(shp1), "ggplot")
-  expect_s3_class(sv_importance(shp1, kind = "beeswarm", groupOnX = FALSE), "ggplot")
+  expect_s3_class(sv_importance(shp1, kind = "beeswarm"), "ggplot")
   expect_s3_class(sv_importance(shp1), "ggplot")
   expect_s3_class(sv_dependence(shp1, "x", color_var = "y"), "ggplot")
   expect_s3_class(sv_dependence(shp1, "x", color_var = "auto"), "ggplot")
